@@ -77,6 +77,31 @@ class TestBlock(unittest.TestCase):
 		self.assertEqual(ret["hash"], "FnyTMUqPNRTdk1Wou7oLqDHkBm_p", "hash not match")
 		rs.Client().delete(bucket, key)
 
+	def test_put_4m(self):
+		ostype = platform.system()
+		if ostype.lower().find("windows") != -1:
+			tmpf = "".join([os.getcwd(), os.tmpnam()])
+		else:
+			tmpf = os.tmpnam()
+		dst = open(tmpf, 'wb')
+		dst.write("abcd" * 1024 * 1024)
+		dst.flush()
+
+		policy = rs.PutPolicy(bucket)
+		extra = resumable_io.PutExtra(bucket)
+		extra.bucket = bucket
+		extra.params = {"x:foo": "test"}
+		key = "sdk_py_resumable_block_6_%s" % r(9)
+		localfile = dst.name
+		ret, err = resumable_io.put_file(policy.token(), key, localfile, extra)
+		assert ret.get("x:foo") == "test", "return data not contains 'x:foo'"
+		dst.close()
+		os.remove(tmpf)
+
+		assert err is None, err
+		self.assertEqual(ret["hash"], "FnIVmMd_oaUV3MLDM6F9in4RMz2U", "hash not match")
+		rs.Client().delete(bucket, key)
+
 
 if __name__ == "__main__":
 	unittest.main()
