@@ -6,14 +6,14 @@ from qiniu import conf
 import os
 conf.ACCESS_KEY = os.getenv("QINIU_ACCESS_KEY")
 conf.SECRET_KEY = os.getenv("QINIU_SECRET_KEY")
-bucket_name = os.getenv("QINIU_BUCKET_NAME")
+bucket_name = os.getenv("QINIU_TEST_BUCKET")
 
 class TestRsf(unittest.TestCase):
 	def test_list_prefix(self):
 		c = rsf.Client()
-		ret, err = c.list_prefix(bucket_name)
-		assert err is rsf.EOF
-		self.assertEqual(len(ret.get('items'))>0, True)
+		ret, err = c.list_prefix(bucket_name, limit = 4)
+		self.assertEqual(err is rsf.EOF or err is None, True)
+		assert len(ret.get('items')) == 4
 
 
 if __name__ == "__main__":
